@@ -38,6 +38,7 @@ extern crate chrono_tz;
 #[macro_use]
 extern crate derivative;
 extern crate dmntk_common;
+extern crate dmntk_feel_number;
 #[macro_use]
 extern crate lazy_static;
 extern crate regex;
@@ -47,10 +48,10 @@ extern crate rust_decimal_macros;
 extern crate thiserror;
 
 pub use ast::{AstNode, OptAstNode};
+pub use dmntk_feel_number::FeelNumber;
 pub use evaluator::Evaluator;
 pub use function::FunctionBody;
 pub use names::{Name, OptName, QualifiedName};
-pub use numbers::FeelNumber;
 pub use scope::Scope;
 pub use strings::ToFeelString;
 pub use temporal::date::FeelDate;
@@ -66,7 +67,6 @@ pub mod context;
 mod evaluator;
 mod function;
 mod names;
-mod numbers;
 mod scope;
 mod strings;
 mod temporal;
